@@ -3,27 +3,30 @@ use warnings;
 
 package ELF::Extract::Sections::Scanner::Objdump;
 BEGIN {
-  $ELF::Extract::Sections::Scanner::Objdump::VERSION = '0.02071411';
+  $ELF::Extract::Sections::Scanner::Objdump::AUTHORITY = 'cpan:KENTNL';
+}
+{
+  $ELF::Extract::Sections::Scanner::Objdump::VERSION = '0.03000101';
 }
 
 # ABSTRACT: An C<objdump> based section scanner.
 
-# $Id:$
 use MooseX::Declare;
 
 
-class ELF::Extract::Sections::Scanner::Objdump
-with ELF::Extract::Sections::Meta::Scanner {
+class ELF::Extract::Sections::Scanner::Objdump with
+  ELF::Extract::Sections::Meta::Scanner {
 
 
 
     use MooseX::Has::Sugar 0.0300;
 
 
-    use MooseX::Types::Moose (qw( Bool HashRef RegexpRef FileHandle Undef Str Int));
+    use MooseX::Types::Moose (
+        qw( Bool HashRef RegexpRef FileHandle Undef Str Int));
 
 
-    use MooseX::Types::Path::Class ('File');
+    use MooseX::Types::Path::Tiny ('File');
 
 
 
@@ -32,7 +35,7 @@ with ELF::Extract::Sections::Meta::Scanner {
         $self->_file($file);
         $self->_filehandle( $self->_objdump );
         return 1;
-    };
+    }
 
 
     method next_section returns (Bool) {
@@ -43,67 +46,81 @@ with ELF::Extract::Sections::Meta::Scanner {
             my ( $header, $offset ) = ( $+{header}, $+{offset} );
             $self->_state( { header => $header, offset => $offset } );
             $self->log->info("objdump -D -F : Section $header at $offset");
-
             return 1;
         }
         $self->_clear_file;
         $self->_clear_filehandle;
         $self->_clear_state;
         return 0;
-    };
+    }
 
 
     method section_offset returns (Int|Undef) {
         if ( not $self->_has_state ) {
-            $self->log->logcroak('Invalid call to section_offset outside of file scan');
+            $self->log->logcroak(
+                'Invalid call to section_offset outside of file scan');
             return;
         }
         return hex( $self->_state->{offset} );
-    };
+    }
 
 
     method section_size returns (Undef) {
-        $self->log->logcroak('Can\'t perform section_size on this type of object.');
+        $self->log->logcroak(
+            'Can\'t perform section_size on this type of object.');
         return;
-    };
+    }
 
 
     method section_name returns (Str|Undef) {
         if ( not $self->_has_state ) {
-            $self->log->logcroak('Invalid call to section_name outside of file scan');
+            $self->log->logcroak(
+                'Invalid call to section_name outside of file scan');
             return;
         }
         return $self->_state->{header};
-    };
+    }
 
 
-    method can_compute_size returns (Bool){
+    method can_compute_size returns (Bool) {
         return 0;
-    };
+    }
 
 
-    has _header_regex => ( isa => RegexpRef, ro, default => sub {
-        return qr/<(?<header>[^>]+)>/;
-    }, );
+    has _header_regex => (
+        isa => RegexpRef,
+        ro,
+        default => sub {
+            return qr/<(?<header>[^>]+)>/;
+        },
+    );
 
 
-    has _offset_regex => ( isa => RegexpRef, ro, default => sub {
-        ## no critic (RegularExpressions::ProhibitEnumeratedClasses)
-        return qr/[(]File Offset:\s*(?<offset>0x[0-9a-f]+)[)]/;
-    }, );
+    has _offset_regex => (
+        isa => RegexpRef,
+        ro,
+        default => sub {
+            ## no critic (RegularExpressions::ProhibitEnumeratedClasses)
+            return qr/[(]File Offset:\s*(?<offset>0x[0-9a-f]+)[)]/;
+        },
+    );
 
 
-    has _section_header_identifier => ( isa => RegexpRef,  ro, lazy_build, );
+    has _section_header_identifier => ( isa => RegexpRef, ro, lazy_build, );
 
 
-    has _file                      => ( isa => File,       rw, clearer => '_clear_file', );
+    has _file => ( isa => File, rw, clearer => '_clear_file', );
 
 
-    has _filehandle                => ( isa => FileHandle, rw, clearer => '_clear_filehandle', );
+    has _filehandle =>
+      ( isa => FileHandle, rw, clearer => '_clear_filehandle', );
 
 
-    has _state                     => ( isa => HashRef,    rw,
-      predicate => '_has_state', clearer => '_clear_state',
+    has _state => (
+        isa => HashRef,
+        rw,
+        predicate => '_has_state',
+        clearer   => '_clear_state',
     );
 
 
@@ -113,22 +130,25 @@ with ELF::Extract::Sections::Meta::Scanner {
         my $offset = $self->_offset_regex;
 
         return qr/${header}\s*${offset}:/;
-    };
+    }
 
 
 
-    method _objdump returns (FileHandle|Undef){
-        if ( open my $fh, q{-|}, q{objdump}, qw( -D -F ), $self->_file->cleanup->absolute ) {
+    method _objdump returns (FileHandle|Undef) {
+        if ( open my $fh,
+            q{-|}, q{objdump}, qw( -D -F ), $self->_file->realpath->absolute )
+        {
             return $fh;
         }
-        $self->log->logconfess(qq{An error occured requesting section data from objdump $^ $@ });
+        $self->log->logconfess(
+            qq{An error occured requesting section data from objdump $^ $@ });
         return;
-    };
+    }
 
-};
+  };
 1;
 
-
+__END__
 
 =pod
 
@@ -138,7 +158,7 @@ ELF::Extract::Sections::Scanner::Objdump - An C<objdump> based section scanner.
 
 =head1 VERSION
 
-version 0.02071411
+version 0.03000101
 
 =head1 SYNOPSIS
 
@@ -174,11 +194,11 @@ Type Constraining Keywords.
 
 L<MooseX::Types::Moose>
 
-=head2 MooseX::Types::Path::Class
+=head2 MooseX::Types::Path::Tiny
 
-File Type Constraints w/ Path::Class
+File Type Constraints w/ Path::Tiny
 
-L<MooseX::Types::Path::Class>
+L<MooseX::Types::Path::Tiny>
 
 =head1 PUBLIC METHODS
 
@@ -220,7 +240,7 @@ L<ELF::Extract::Sections::Meta::Scanner/can_compute_size>
 
 =head1 PRIVATE ATTRIBUTES
 
-=head2 -> _header_regex : RegexpRef
+=head2 _header_regex : RegexpRef
 
 A regular expression for identifying the
 
@@ -230,7 +250,7 @@ Style tokens that denote objdump header names.
 
 Note: This is not XML.
 
-=head2 -> _offset_regex : RegexpRef
+=head2 _offset_regex : RegexpRef
 
 A regular expression for identifying offset blocks in objdump's output.
 
@@ -238,31 +258,39 @@ They look like this:
 
   File Offset: 0xdeadbeef
 
-=head2 -> _section_header_identifier : RegexpRef
+=head2 _section_header_identifier : RegexpRef
 
 A regular expression for extracting Headers and Offsets together
 
   <headername> File Offset: 0xdeadbeef
 
-=head2 -> _file : File
+=head2 _file : File
 
-A L<Path::Class::File> reference to a file somewhere on a system
+A L<Path::Tiny> reference to a file somewhere on a system
 
-=head3 clearer -> _clear_file
+=head3 _clear_file : _file.clearer
 
-=head2 -> _filehandle : FileHandle
+Clears L</_file>
+
+=head2 _filehandle : FileHandle
 
 A perl FileHandle that points to the output of objdump for L</_file>
 
-=head3 clearer -> _clear_file_handle
+=head3 _clear_file_handle : _filehandle.clearer
 
-=head2 -> _state : HashRef
+Clears L</_filehandle>
+
+=head2 _state : HashRef
 
 Keeps track of what we're doing, and what the next header is to return.
 
-=head3 predicate -> _has_state
+=head3 _has_state : _state.predicate
 
-=head3 clearer   -> _clear_state
+Returns is-set of L</_state>
+
+=head3 _clear_state : _state.clearer
+
+Clears L<_state>
 
 =head1 PRIVATE ATTRIBUTE BUILDERS
 
@@ -284,13 +312,9 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Kent Fredric.
+This software is copyright (c) 2013 by Kent Fredric.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
